/*
 * $Id: extension-loader.h,v 1.4 2011-12-28 00:52:05 miras Exp $
 */
/* vim:et:ts=4:sw=4:et:sts=4:ai:set list listchars=tab\:,trail\:: */

/*
 * Claws-contacts is a proposed new design for the address book feature
 * in Claws Mail. The goal for this new design was to create a
 * solution more suitable for the term lightweight and to be more
 * maintainable than the present implementation.
 *
 * More lightweight is achieved by design, in that sence that the whole
 * structure is based on a plugable design.
 *
 * Claws Mail is Copyright (C) 1999-2011 by the Claws Mail Team and
 * Claws-contacts is Copyright (C) 2011 by Michael Rasmussen.
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program. If not, see <http://www.gnu.org/licenses/>.
 * 
 */

#ifndef __EXTENSION_LOADER_H__
#define __EXTENSION_LOADER_H__

#include <glib.h>

G_BEGIN_DECLS

#include <gtk/gtk.h>
#include "extension.h"
#include "mainwindow.h"

typedef struct {
	gchar*			filename;
	guint			id;
	GModule*		module;
	gint			(*init) (guint id);
	gboolean		(*done) (void);
	const gchar*	(*license) (void);
	const gchar*	(*name) (void);
	const gchar*	(*describtion) (void);
} Extension;

typedef struct {
	const gchar*	parent;
	const gchar*	sublabel;
	GtkWidget*		menu;
	GtkWidget*		widget;
} UserMenuItem;

void init_hooks(MainWindow* main);
void run_hook_callbacks(ExtensionHook hook, gpointer object);
void done_hooks(void);
Extension* extension_load(const gchar* filename, gchar** error);
void extension_unload(Extension** extension, gchar** error);
void extension_loader_done(void);
void load_extensions(gchar** error);
void unload_extensions(void);
GSList* get_menu_items(ContactsMenu menu);

G_END_DECLS

#endif
